ConnectBuilder

Struct ConnectBuilder 

pub struct ConnectBuilder<T = TungsteniteTransport, C = JsonCodec> { /* private fields */ }
Builder for advanced connection configuration.

Allows customizing the transport and codec used for the connection. Defaults to TungsteniteTransport + JsonCodec.

Example

use gemini_genai_rs::prelude::*;

let config = SessionConfig::new("key");
let handle = ConnectBuilder::new(config)
    .transport_config(TransportConfig { connect_timeout_secs: 30, ..Default::default() })
    .build()
    .await
    .unwrap();

Implementations

Source

impl ConnectBuilder

pub fn new(config: SessionConfig) -> Self

Create a new builder with default transport and codec.

Source

impl<T: Transport, C: Codec> ConnectBuilder<T, C>

pub fn transport_config(self, tc: TransportConfig) -> Self

Set the transport configuration.

pub fn transport<T2: Transport>(self, transport: T2) -> ConnectBuilder<T2, C>

Use a custom transport implementation.

pub fn codec<C2: Codec>(self, codec: C2) -> ConnectBuilder<T, C2>

Use a custom codec implementation.

pub async fn build(self) -> Result<SessionHandle, SessionError>

Build the connection and return a SessionHandle.